#
# spec file for package libunwind
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define realver 1.2.1
Name:           libunwind
Version:        1.2.1
Release:        lp150.2.1
Summary:        Unwind Library
License:        MIT
Group:          System/Base
Url:            http://savannah.nongnu.org/projects/libunwind/
Source0:        http://download.savannah.gnu.org/releases/%{name}/%{name}-%{realver}.tar.gz
Source1:        http://download.savannah.gnu.org/releases/%{name}/%{name}-%{realver}.tar.gz.sig
Source2:        %{name}.keyring
Source3:        baselibs.conf
# PATCH-FIX-UPSTREAM fix_versioning_libunwind_1.2.1.patch gh#libunwind/libunwind#30 ronisbr@gmail.com -- libunwind 1.2.1 UNW_VERSION_MINOR is not an integer.
Patch0:         fix_versioning_libunwind_1.2.1.patch
BuildRequires:  gcc-c++
BuildRequires:  lzma-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(atomic_ops)
ExclusiveArch:  %{ix86} ia64 x86_64 %{arm} ppc ppc64 ppc64le aarch64

%description
A portable and efficient C programming interface (API) to determine the
call chain of a program.

%package devel
Summary:        Unwind library
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
A portable and efficient C programming interface (API) to determine the
call-chain of a program.

%prep
%setup -q -n %{name}-%{realver}
%patch0 -p1

%build
%configure \
    --enable-minidebuginfo
make %{?_smp_mflags}

%check
%if ! 0%{?qemu_user_space_build:1}
# run-coredump-unwind fails
make check %{?_smp_mflags} || :
%endif

%install
%make_install
find %{buildroot} -iregex '.*\.l?a$' -delete -print

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%{_libdir}/lib*.so.*

%files devel
%{_includedir}/*
%{_libdir}/%{name}*.so
%{_libdir}/pkgconfig/%{name}*.pc

%changelog
* Sun Feb 18 2018 ronisbr@gmail.com
- Add patch `fix_versioning_libunwind_1.2.1.patch`.
  * This patch fixes the upstream bug gh#libunwind/libunwind#30.
    This bug was causing the julia build process to fail.
    NOTE: This patch shall be removed in the next version of
    libunwind.
* Fri Feb  2 2018 tchvatal@suse.com
- Update keyring
* Wed Jan 24 2018 avindra@opensuse.org
- Upgrade to 1.2.1
  * minor package fixes for tilegx, mips, others
  * fix missing include file issues
- cleanup with spec-cleaner
- do not ship static libraries
* Mon Jun 20 2016 tchvatal@suse.com
- Enable minidebugs parsing with lzma
* Tue May 17 2016 tchvatal@suse.com
- Version update to 1.2-rc1, should include all our patches:
  * 0001-Mark-run-ptrace-mapper-and-run-ptrace-misc-as-XFAIL-.patch
  * 0002-Mark-run-ptrace-mapper-and-run-ptrace-misc-as-XFAIL-.patch
  * libunwind-1.1-expected-fails.patch
  * libunwind-CVE-2015-3239.patch
  * libunwind-aarch64.patch
  * libunwind-ppc64le.patch
  * libunwind-1.1-tests.diff
* Sun Apr 24 2016 matwey.kornilov@gmail.com
- Add patches for boo#976955:
  * 0001-Mark-run-ptrace-mapper-and-run-ptrace-misc-as-XFAIL-.patch
  * 0002-Mark-run-ptrace-mapper-and-run-ptrace-misc-as-XFAIL-.patch
* Thu Jul  2 2015 tchvatal@suse.com
- Add patch for bnc#936786 CVE-2015-3239, off by one:
  * libunwind-CVE-2015-3239.patch
* Sun Mar 29 2015 meissner@suse.com
- added baselibs.conf for -xxbit packages
* Wed Mar  4 2015 mpluskal@suse.com
- Use url for source
- Add gpg signature
* Mon May 19 2014 tchvatal@suse.com
- Clean up with spec-cleaner
- Add dependency over libatomic_opts that was missing
- Do not disable fortify-sources as it seems to work with it anyway
* Tue Dec 17 2013 uweigand@de.ibm.com
- libunwind-ppc64le.patch: Add support for ppc64le
* Wed Dec 11 2013 dvaleev@suse.com
- add ppc64le
* Mon Aug 12 2013 schwab@suse.de
- libunwind-aarch64.patch: Add support for AArch64 from upstream
* Sat Jan 26 2013 dmueller@suse.com
- filelist fix for ARM
* Tue Dec 11 2012 dvaleev@suse.com
- update to libunwind 1.1:
    coredump unwind support
    New arch: SuperH
    Improved support for PowerPC, ARM
    Lots of cleanups, perf tweaks
    pkg-config support
- drop all upstreamed patches
- refresh libunwind-1.1-tests.diff patch
- enable ppc ppc64 build
- Mark some tests as expected to fail
  libunwind-1.1-expected-fails.patch
* Mon Aug 20 2012 agraf@suse.com
- add support for ARM
* Mon Mar  5 2012 dmueller@suse.de
- remove build from ARM
* Thu Feb  9 2012 jengelh@medozas.de
- Remove redundant tags/sections
- Fix dangling symlink /usr/lib/libunwind.so (which was
  pointing at "libunwind.so.8.*", verbatim asterisk)
- Throw out .la file
* Wed Nov 23 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Mon Nov  7 2011 dmueller@suse.de
- disable testsuite when running under qemu
* Mon Oct 17 2011 dmueller@suse.de
-  update to libunwind 1.0.1:
  * hundreds of fixes, see http://git.savannah.gnu.org/gitweb/?p=libunwind.git;a=shortlog
    for details
  * ARM support
  * Greatly improved x86-64 support thanks to Arun Sharma.
  * Support for PPC64 added by  Jose Flavio Aguilar Paulino.
  * Testing, stability and many fixes on x86 (Paul Pluzhnikov)
  * Improved local and remote unwinding on ARM (Ken Werner)
  * Fast unwind (rbp, rsp, rip only) on x86_64 with a fallback to slow code paths
* Sun Oct 31 2010 jengelh@medozas.de
- Use %%_smp_mflags
* Thu Jan 28 2010 rguenther@suse.de
- Build without _FORTIFY_SOURCE, recent glibc fortify longjmp which
  confuses libunwind a lot and breaks the build.
* Thu Oct 15 2009 marek.belisko@open-nandra.com
- Fix typo in Gtest-dyn1.c (bnc#531705)
* Mon Jan 26 2009 schwab@suse.de
- Fix overlapping memcpy.
* Tue May 13 2008 schwab@suse.de
- Update to libunwind 0.98.6.
  * * Fix address-leak triggered by invalid byte-order.  Fixed by Andreas Schwab.
  * * On ia64, get_static_proc_name() no longer uses a weak reference to
    _Uelf64_get_proc_name(), since that was causing problems with archive
    libraries and no longer served any apparent purpose.  Fixed by
    Curt Wohlgemuth.
* Fri Apr 18 2008 rguenther@suse.de
- Fix build.
* Wed Jun  6 2007 schwab@suse.de
- Fix memory leak.
* Thu Jan 26 2006 schwab@suse.de
- Run ldconfig.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Nov 14 2005 schwab@suse.de
- Undo last change.
* Mon Oct 31 2005 dmueller@suse.de
- build with nonexecutable stack
* Fri Jul 22 2005 schwab@suse.de
- Remove broken tests.
* Mon May  2 2005 schwab@suse.de
- Fix broken test.
* Sat Apr 23 2005 schwab@suse.de
- Only libunwind needs to be in /lib.
- There are no expected testsuite failures on ia64 any more.
* Thu Apr 21 2005 schwab@suse.de
- Update to libunwind 0.98.5.
* Fri Feb 25 2005 schwab@suse.de
- Update to libunwind 0.98.4.
* Thu Feb  3 2005 schwab@suse.de
- Fix libdir.
- Fix warning.
* Tue Dec  7 2004 schwab@suse.de
- Update to libunwind 0.98.3.
* Sun Nov 14 2004 schwab@suse.de
- Don't move around libtool libraries.
* Sun Nov 14 2004 schwab@suse.de
- Split off libunwind-devel.
- Move library to /lib.
- Remove broken test.
* Fri Nov  5 2004 schwab@suse.de
- Update to libunwind 0.98.2.
* Thu Oct 28 2004 schwab@suse.de
- Update to libunwind 0.98.1.
* Wed Sep 29 2004 schwab@suse.de
- Fix installed headers.
* Thu Sep  9 2004 schwab@suse.de
- Update to libunwind 0.98.
- Enable building on x86_64.
* Thu Aug 19 2004 schwab@suse.de
- Update to libunwind 0.97.
* Sun Apr 18 2004 schwab@suse.de
- Pacify autobuild.
* Fri Dec  5 2003 schwab@suse.de
- Update to libunwind 0.96.
* Thu Dec  4 2003 schwab@suse.de
- Update to libunwind 0.95.
* Fri Sep 26 2003 schwab@suse.de
- Update to libunwind 0.93.
* Wed Jul 23 2003 schwab@suse.de
- Fix typo in specfile.
* Thu Jul 11 2002 schwab@suse.de
- Initial version.
